# libspeechcomparison

## Build it

You will need to install some dependencies. On Red Hat/Fedora based
distributions these can be installed with yum|dnf e.g

    $ sudo dnf install libsamplerate-devel libsndfile-devel

This also requires libsvm, however upstream is broken when used with threads.
Use our fixed version

Firstly create a rpm build directory strucutre

    $ mkdir -p ~/rpmbuild/{BUILD,RPMS,SOURCES,SPECS,SRPMS}

    $ git clone http://stash.denovolab.com/scm/~clayton/libsvm.git
    $ cd libsvm
    $ git checkout -b denovolab -t origin/denovolab
    $ git archive --prefix=libsvm-3.23/ -o ~/rpmbuild/SOURCES/libsvm-3.23.tar HEAD
    $ rpmbuild -bb libsvm.spec

Install the libsvm package. Now you can move onto libspeechcomparison.

Now you should be ready to build it. Type 'make' in the repository root.

You can also generate a rpm package with the following

    $ git archive --prefix=libspeechcomparison-0.0.0/ -o ~/rpmbuild/SOURCES/libspeechcomparison-0.0.0.tar HEAD
    $ rpmbuild -bb libspeechcomparison.spec

## Run it

Type './run.sh' to run the test program.

The test program makes use of three files:

    1) Sample.wav is a wave file created by TTS,
    2) Benchmark.wav is a recorded wave file.
    3) words.txt is a text file that includes a translation of Sample.wav.

The test program should output:

	Phrase
	    Nice day as the weather is warm 

	nice	0.02, 0.29	2.77, 3.18
	day	0.35, 0.59	3.18, 3.73
	as	0.59, 0.74	3.73, 4.04
	the	0.74, 0.85	4.04, 4.22
	weather	0.85, 1.24	4.22, 4.97
	is	1.24, 1.41	5.76, 6.20
	warm	1.41, 1.96	6.26, 6.78
	

	  DTW-based Align Result:
	-Word-          -Benchmark-           -Sample-           
			([ 0.00,  2.26] - [ 0.00,  7.85])
	nice           : [ 0.02,  0.29] - [ 2.77,  3.18]
	day            : [ 0.35,  0.59] - [ 3.18,  3.73]
	as             : [ 0.59,  0.74] - [ 3.73,  4.04]
	the            : [ 0.74,  0.85] - [ 4.04,  4.22]
	weather        : [ 0.85,  1.24] - [ 4.22,  4.97]
	is             : [ 1.24,  1.41] - [ 5.76,  6.20]
	warm           : [ 1.41,  1.96] - [ 6.26,  6.78]

	 Wrong Accent and Tone Detection Result:
	-Word-          -Accent-    -Tone-   
	nice           : correct    wrong      (214 114)
	day            : wrong      wrong      (131 114)
	as             : correct    correct    (111 111)
	the            : correct    correct    (113 113)
	weather        : correct    correct    (214 214)
	is             : correct    wrong      (213 113)
	warm           : wrong      correct    (111 114)

	 Mispronunciation Detection Result:
	-Word-          -Evaluation-
	nice           : correct
	day            : correct
	as             : correct
	the            : correct
	weather        : correct
	is             : correct
	warm           : correct


	 Correct words:
		as  the  weather  
	 Pronounce Error:
	
	 Tone Error:
		nice  day  is  
	 Accent Error:
		day  warm  


If command arguments are missed, usage message will be printed.

	Arguments required: [t_wav_name] [s_wav_name] [word_file]
		t_wav_name : wav file of standard TTS (Sample.wav)
		s_wav_name : wav file for SpeechComparison (Benchmark.wav)
		word_file  : content text of wav file
	Here, all audio files should be in WAV format.
	Those wav files are converted to 16KHz, mono, 16bit data and processed
	in program.

## Using it

Take a copy of docs/Makefile.tmpl and rename to Makefile and set the APPNAME
variable.

You can use src/test/test.c as a starting place, though it's pretty simple.

One thing to note is that the above output is simply stored in a character
array and is displayed to stdout via the ad\_print\_results() function.

You can access this directly if needed via ad\_words-\>rptr and its size is
in ad\_words-\>rsize.
